@@ -2,10 +2,10 @@ from dbnd import parameter
 from dbnd._core.constants import ClusterPolicy, EmrClient, SparkClusters
 from dbnd._core.errors import DatabandConfigError
 from dbnd._core.plugin.dbnd_plugins import assert_airflow_package_installed
-from dbnd._core.task.config import Config
+from dbnd_spark.spark_config import SparkEngineConfig
 
 
-class EmrConfig(Config):
+class EmrConfig(SparkEngineConfig):
     """Amazon Elastic MapReduce"""
 
     _conf__task_family = "emr"
